aboutsummaryrefslogtreecommitdiffstats
path: root/participant/participant-intermediary
diff options
context:
space:
mode:
authorFrancescoFioraEst <francesco.fiora@est.tech>2023-05-17 11:21:25 +0100
committerFrancescoFioraEst <francesco.fiora@est.tech>2023-05-18 09:44:31 +0100
commit22413b34218e632c509c1b8b87dbfcc5644b5abd (patch)
treeaad47135165c03c62dffa1ac40b69039e5786de7 /participant/participant-intermediary
parentdb6eb3fc07398e31dfa664992117f33fa8489cec (diff)
Rename statusProperites to outProperites in ACM
Issue-ID: POLICY-4687 Change-Id: Ida8ff3fbc72c2f6d75a8e3399fa40099696c1477 Signed-off-by: FrancescoFioraEst <francesco.fiora@est.tech>
Diffstat (limited to 'participant/participant-intermediary')
-rw-r--r--participant/participant-intermediary/src/main/java/org/onap/policy/clamp/acm/participant/intermediary/api/ParticipantIntermediaryApi.java4
-rw-r--r--participant/participant-intermediary/src/main/java/org/onap/policy/clamp/acm/participant/intermediary/api/impl/ParticipantIntermediaryApiImpl.java4
-rw-r--r--participant/participant-intermediary/src/main/java/org/onap/policy/clamp/acm/participant/intermediary/handler/AutomationCompositionHandler.java10
3 files changed, 9 insertions, 9 deletions
diff --git a/participant/participant-intermediary/src/main/java/org/onap/policy/clamp/acm/participant/intermediary/api/impl/ParticipantIntermediaryApiImpl.java b/participant/participant-intermediary/src/main/java/org/onap/policy/clamp/acm/participant/intermediary/api/impl/ParticipantIntermediaryApiImpl.java
index 69fd9f3e8..1bc3e5e72 100644
--- a/participant/participant-intermediary/src/main/java/org/onap/policy/clamp/acm/participant/intermediary/api/impl/ParticipantIntermediaryApiImpl.java
+++ b/participant/participant-intermediary/src/main/java/org/onap/policy/clamp/acm/participant/intermediary/api/impl/ParticipantIntermediaryApiImpl.java
@@ -65,9 +65,9 @@ public class ParticipantIntermediaryApiImpl implements ParticipantIntermediaryAp
@Override
public void sendAcElementInfo(UUID automationCompositionId, UUID elementId, String useState,
- String operationalState, Map<String, Object> statusProperties) {
+ String operationalState, Map<String, Object> outProperties) {
automationCompositionHandler.sendAcElementInfo(automationCompositionId, elementId, useState, operationalState,
- statusProperties);
+ outProperties);
}
@Override
diff --git a/participant/participant-intermediary/src/main/java/org/onap/policy/clamp/acm/participant/intermediary/api/ParticipantIntermediaryApi.java b/participant/participant-intermediary/src/main/java/org/onap/policy/clamp/acm/participant/intermediary/api/ParticipantIntermediaryApi.java
index f35572769..550ac37c5 100644
--- a/participant/participant-intermediary/src/main/java/org/onap/policy/clamp/acm/participant/intermediary/api/ParticipantIntermediaryApi.java
+++ b/participant/participant-intermediary/src/main/java/org/onap/policy/clamp/acm/participant/intermediary/api/ParticipantIntermediaryApi.java
@@ -66,8 +66,8 @@ public interface ParticipantIntermediaryApi {
* @param id the ID of the automation composition element to update the states
* @param useState the use State
* @param operationalState the operational State
* @param statusProperties the status Properties Map
*/
void sendAcElementInfo(UUID automationCompositionId, UUID id, String useState, String operationalState,
- Map<String, Object> statusProperties);
+ Map<String, Object> outProperties);
}
@@ -66,8 +66,8 @@ public interface ParticipantIntermediaryApi {
* @param useState the use State
* @param operationalState the operational State
- * @param statusProperties the status Properties Map
+ * @param outProperties the output Properties Map
*/
void sendAcElementInfo(UUID automationCompositionId, UUID id, String useState, String operationalState,
diff --git a/participant/participant-intermediary/src/main/java/org/onap/policy/clamp/acm/participant/intermediary/handler/AutomationCompositionHandler.java b/participant/participant-intermediary/src/main/java/org/onap/policy/clamp/acm/participant/intermediary/handler/AutomationCompositionHandler.java
index 26ec1462c..d33498518 100644
--- a/participant/participant-intermediary/src/main/java/org/onap/policy/clamp/acm/participant/intermediary/handler/AutomationCompositionHandler.java
+++ b/participant/participant-intermediary/src/main/java/org/onap/policy/clamp/acm/participant/intermediary/handler/AutomationCompositionHandler.java
@@ -154,7 +154,7 @@ public class AutomationCompositionHandler {
automationCompositionStateChangeAck.setAutomationCompositionId(automationCompositionId);
automationCompositionStateChangeAck.getAutomationCompositionResultMap().put(element.getId(),
new AcElementDeployAck(element.getDeployState(), element.getLockState(), element.getOperationalState(),
- element.getUseState(), element.getStatusProperties(), true,
+ element.getUseState(), element.getOutProperties(), true,
"Automation composition element {} state changed to {}\", id, newState)"));
LOGGER.debug("Automation composition element {} state changed to {}", id, deployState);
automationCompositionStateChangeAck.setResult(true);
@@ -509,10 +509,10 @@ public class AutomationCompositionHandler {
* @param elementId the automationComposition Element id
* @param useState the use State
* @param operationalState the operational State
* @param statusProperties the status Properties Map
*/
public void sendAcElementInfo(UUID automationCompositionId, UUID elementId, String useState,
- String operationalState, Map<String, Object> statusProperties) {
+ String operationalState, Map<String, Object> outProperties) {
if (automationCompositionId == null || elementId == null) {
LOGGER.error("Cannot update Automation composition element state, id is null");
@@ -534,7 +534,7 @@ public class AutomationCompositionHandler {
}
element.setOperationalState(operationalState);
element.setUseState(useState);
- element.setStatusProperties(statusProperties);
+ element.setOutProperties(outProperties);
var statusMsg = new ParticipantStatus();
statusMsg.setParticipantId(participantId);
@@ -576,7 +576,7 @@ public class AutomationCompositionHandler {
elementInfo.setLockState(element.getLockState());
elementInfo.setOperationalState(element.getOperationalState());
elementInfo.setUseState(element.getUseState());
- elementInfo.setStatusProperties(element.getStatusProperties());
+ elementInfo.setOutProperties(element.getOutProperties());
return elementInfo;
}
}
@@ -509,10 +509,10 @@ public class AutomationCompositionHandler {
* @param useState the use State
* @param operationalState the operational State
- * @param statusProperties the status Properties Map
+ * @param outProperties the output Properties Map
*/
public void sendAcElementInfo(UUID automationCompositionId, UUID elementId, String useState,